%brachistochrone
% Curve of fastest descent for a bead sliding frictionlessly along a wire
% in a uniform gravitational field.
% 
% LAST UPDATED by Andy French December 2017

function brachistochrone

%% Inputs %%

%Start and finish coordinates
xa = 1;
ya = 3;
xb = 5;
yb = 1;

%Number of evaluation points
N = 1000;

%Fontsize
fsize = 16;

%

%Determine end theta value /radians of cycloid curve

%Plot theta vs implicit function to determine solution
a = (ya-yb)/(xb - xa);
theta = linspace(0,2*pi,N);
f = (1 - cos(theta))/a + sin(theta) - theta;
figure; plot( theta, f )
xlabel('\theta','fontsize',fsize)
ylabel('f(\theta)','fontsize',fsize)
set( gca,'fontsize',fsize )
grid on
axis tight
print( gcf, 'brachistochrone - iteration.png','-dpng','-r300');
close(gcf)

%Solve using Newton-Raphson method
t = 4;
tt = t;
dt_min = 1e-6;
dt = 1;
iter = 0;
while ( dt > dt_min ) && ( iter < 100 )
    iter = iter + 1;
    f = (1 - cos(t))/a + sin(t) - t;
    fdash = sin(t)/a + cos(t) - 1;
    tt(iter) = t - f/fdash;
    dt = abs( tt(iter) - t );
    t = tt(iter);
end
%figure; plot( 1:iter, tt )

%Determine cycloid constant
c = (ya - yb)/ (1-cos(t));

%Determine cycloid curve
theta = linspace(0,t,N);
x = xa + c*( theta - sin(theta));
y = ya - c*( 1 - cos(theta) );

%Plot curve
figure('color',[1 1 1],'name','Brachistochrone')
plot(x,y,'b');
hold on;
plot(xa,ya,'g*')
plot(xb,yb,'r*')
xlabel('x','fontsize',fsize)
ylabel('y','fontsize',fsize)
title({'Brachistochrone problem',['\theta_b = ',num2str(t),', c = ',num2str(c)]},...
    'fontsize',fsize)
set( gca,'fontsize',fsize )
grid on
axis equal
xlim([0,xb+1])
ylim([0,ya+1])
print( gcf, 'brachistochrone.png','-dpng','-r300');
close(gcf)

%End of code