%catenary
% Determines the minimum-GPE curve of a uniform inextensible chain 
% of length L hung between two points (-a, H) and (a, h).
%
% LAST UPDATED by Andy French December 2017

function catenary

%% Inputs %%

%Length of chain /m
L = 10;

%Mass per unit length rho /kg/m
rho = 1;

%Gravitational field strength g /N/kg
g = 9.81;

%Start and end points
a = 2;
H = 5;
h = 1;

%Fontsize
fsize = 18;

%%

%Check chain can hang between points
min_L = sqrt( (2*a)^2 + (H-h)^2 );
if L > min_L
    disp(['Chain length ',num2str(L),' is greater than distance ',num2str(min_L),' between points.']);
else
    disp('Chain not long enough to hang between points chosen.')
    return
end

%Determine constant k
k = linspace(0,rho*g*a,10000);
f = (2*k/(rho*g)).*sinh( rho*g*a./k );

%Step through f and find k when f < L*sqrt( 1- ((H-h)/L)^2 )
for n=1:length(f)
    if f(n)< L*sqrt( 1- ((H-h)/L)^2 )
        kk = 0.5*( k(n) + k(n-1) );
        break
    end
end
plot( k, f, 'b', k, L*sqrt( 1- ((H-h)/L)^2 )*ones(size(k)),'r' )
ylim([0,2*L])
xlabel('k','fontsize',fsize)
ylabel('f(k)','fontsize',fsize)
title(['k = ',num2str(kk)],'fontsize',fsize)
grid on;
set(gca,'fontsize',fsize)
print(gcf,'catenary - finding k.png','-dpng','-r300')
close(gcf);

%Generate and plot catenary
x = linspace( -a, a, 1000);
c = -(kk/(rho*g))*atanh( (H-h)/L );
lambda = kk*cosh( rho*g*(a+c)/kk ) -h*rho*g;
y = (kk/(rho*g))*cosh( rho*g*(x+c)/kk ) - lambda/(rho*g);
plot(x,y,'b')
hold on
plot(-a,H,'g*')
plot(a,h,'r*')
xlabel('x','fontsize',fsize)
ylabel('y','fontsize',fsize)
title(['Catenary k = ',num2str(kk),', c = ',...
    num2str(c),', \lambda = ',num2str(lambda)],'fontsize',fsize)
grid on;
axis equal
set(gca,'fontsize',fsize)
print(gcf,'catenary.png','-dpng','-r300')
close(gcf);

%End of code