%fermat_ray
% Fermat's principle of minimum travel time is applied to predict the curve
% of a ray in a medium in which the speed of wave propagation varies
% linearly with depth (y /km).
%
% LAST UPDATED by Andy French December 2017

function fermat_ray

%% Inputs %%

%Takeoff agle /radians
theta = 45*pi/180;

%Number of evaluation points
N = 1000;

%x limits /km
xmax = 10;

%Speed of wave propagation /kms^-1 v = alpha + beta*y
alpha = 0.33;
beta = 0.1;

%Fontsize
fsize = 18;

%

%Define x,y values for ray
x = linspace(0,xmax,N);
y = (1/beta)*sqrt( alpha^2 -(beta*x).^2 + 2*beta*x*alpha*tan(theta) ) -alpha/beta;
x(y<0)=[];
y(y<0)=[];
k = ( alpha^2 -(beta*x).^2 + 2*beta*x*alpha*tan(theta) < 0 );
x(k) = [];
y(k) = [];

%Plot ray path
plot(x,y);
xlabel('x /km','fontsize',fsize);
ylabel('y /km','fontsize',fsize);
set(gca,'fontsize',fsize);
title({['Fermat ray path: \theta = ',num2str(theta*180/pi),'^o, v = \alpha + \betay'],...
    ['\alpha = ',num2str(alpha),'km/s, \beta = ',num2str(beta),'(km/s)/km']},'fontsize',fsize);
hold on
plot(0,0,'g*')
grid on;
axis tight
axis equal
ylimits = get(gca,'ylim');
ylim([0,ylimits(2)])
print( gcf,'fermat ray.png','-dpng','-r300')
close(gcf)

%End of code