%soap_bubble_surface
% Determines the minimal surface between circular hoops position on axis.
% LAST UPDATED by Andy French December 2017

function soap_bubble_surface

%% Inputs %%

%Hoop radii
R = 3;
r = 1;

%Hoop separation is 2a
a = 1;

%Fontsize
fsize = 18;

%Number of evaluation points
N = 500;

%

%Determine parameter alpha (note there might be two values!)
alpha = linspace(0,R,1000);
c = -asinh( (R-r)./(2*alpha.*sinh( a./alpha ) ) );
f = alpha.*cosh( a./alpha + c );
k=1;
A1 = NaN;
A2 = NaN;
for n=1:length(alpha)
    if (f(n)<r) && (k==1)
        A1 = 0.5*( alpha(n) + alpha(n-1) );
        k=-1;
    elseif (f(n)>r) && (k==-1)
        A2 = 0.5*( alpha(n) + alpha(n-1) );
        k=1;
    end
end
plot( alpha, f,alpha,r*ones(size(alpha)))
ylim([0,R])
xlim([0,R/2])
set(gca,'fontsize',fsize)
xlabel('\alpha','fontsize',fsize)
ylabel('f(\alpha)','fontsize',fsize)
grid on;
title(['\alpha = ',num2str(A1), ' or ',num2str(A2)],'fontsize',fsize)
print(gcf,'soap_bubble_alpha.png','-dpng','-r300')
close(gcf)

%Choose smallest alpha, since minima surface
A = min([A1,A2]);

%Determine soap bubble y vs x curve
if A1<A2
    c = -asinh( (R-r)/(2*A1*sinh( a/A1 ) ) );
else
    c = -asinh( (R-r)/(2*A2*sinh( a/A2 ) ) );
end
x = linspace(-a,a,N);
y = A1*cosh( x/A + c );
plot(x,y,'b',-a,R,'g*',a,r,'r*');
xlim([-a,a])
ylim([0,max(R,r)])
grid on
xlabel('x','fontsize',fsize)
ylabel('y','fontsize',fsize)
title({'Height of soap bubble minimal surface',...
    ['\alpha = ',num2str(A),', ',' c = ',num2str(c)]},'fontsize',fsize)
set(gca,'fontsize',fsize)
print(gcf,'soap_bubble.png','-dpng','-r300')
close(gcf)

%Define soap bubble surface
theta = linspace(0,2*pi,N);
yR = R*cos(theta);
zR = R*sin(theta);
yr = r*cos(theta);
zr = r*sin(theta);
[yy,theta] = meshgrid(y,theta);
Y = yy.*sin(theta);
Z = yy.*cos(theta);
X = repmat(x,[N,1]);

%Plot surface
surf(X,Y,Z);
axis equal
axis vis3d 
shading interp
interp_colormap(N);
hold on

%Add catenary lines
plot3(x,y,zeros(size(x)),'k-','linewidth',2)
plot3(x,-y,zeros(size(x)),'k-','linewidth',2)
plot3(x,zeros(size(x)),y,'k-','linewidth',2)
plot3(x,zeros(size(x)),-y,'k-','linewidth',2)

%Add hoops
plot3(-a*ones(size(x)),yR,zR,'b-','linewidth',2)
plot3(a*ones(size(x)),yr,zr,'b-','linewidth',2)

%Remove axis, set view, print PNG and close
axis off
view([44,13])
print(gcf,'soap_bubble 3d.png','-dpng','-r300')
close(gcf)

%%

%interp_colormap
% Function which interpolates current colourmap to yield better graduated
% shading. N is number of possible colours.
%
% LAST UPDATED by Andy French 14 September 2008

function interp_colormap( N )

%Get current colourmap
map = colormap;

%Initialise new colormap
new_map = ones(N,3);

%Get size of current colormap and initalise red,green,blue vectors
dim = size(map);
R = ones(1,dim(1));
G = ones(1,dim(1));
B = ones(1,dim(1));
RR = ones(1,N);
GG = ones(1,N);
BB = ones(1,N);

%Populate these with current colormap
R(:) = map(:,1);
G(:) = map(:,2);
B(:) = map(:,3);

%Interpolate to yield new colour map
x = linspace( 1, dim(1), N );
RR = interp1( 1:dim(1), R, x );
GG = interp1( 1:dim(1), G, x );
BB = interp1( 1:dim(1), B, x );
new_map(:,1) = RR(:);
new_map(:,2) = GG(:);
new_map(:,3) = BB(:);

%Set colormap to be new map
colormap( new_map );

%End of code